@@ -1,12 +1,12 @@
 
-context("Auth")
+# context("Auth")
 
-test_that("We can login", {
-  skip_on_cran()
-  
-  expect_is(gce_auth(), "Token2.0")
-  
-})
+# test_that("We can login", {
+#   skip_on_cran()
+#   
+#   expect_is(gce_auth(), "Token2.0")
+#   
+# })
 
 context("Projects")
 
