@@ -1,3 +1,4 @@
+
 context("Machine types")
 
 test_that("We can list machinetypes", {
@@ -52,7 +53,7 @@ test_that("We can change a machine type", {
   
   expect_equal(mt$kind, "compute#operation")
   
-  job <- gce_check_zone_op(mt$name)
+  job <- gce_wait(mt)
   
   expect_equal(job$status, "DONE")
   
@@ -62,7 +63,7 @@ test_that("We can change a machine type", {
   
   expect_equal(mt$kind, "compute#operation")
   
-  job <- gce_check_zone_op(mt$name)
+  job <- gce_wait(mt)
   
   expect_equal(job$status, "DONE")
   
